Welcome to snowline's documentation!
======================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   readme
   installation
   example.ipynb
   contributing
   history
   issues
   modules

.. include:: ../README.rst

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
